#define VER "1.00"
#define hex2bin(str) strtol(str,NULL,16)

//////////////////////////////////////////////////////////////////////////
//
// FR2CAP.CPP
//
//	V 1.0   12/02/96	     	Jerry Merrill
//		- Initial Release
//
//
/////////////////////////////////////////////////////////////////////////
//
// This is a COMMAND-LINE program to read the capture
// register, status pins and flags in a specified emulator.


#include <stdio.h>
#include <stdlib.h>
#include <conio.h>
#include <dos.h>
#include <string.h>
#include "fr2util.h"

// local prototypes
void print_usage(void);

// local variables
char *strptr;
unsigned char e_count;        // number of emulators attached
unsigned long cap_add;        // capture address
unsigned int stat;            // status


// default parameters
unsigned int  port_addr   = 0x378; // MOST COMMON PRINTER ADDRESS
unsigned int  pace        = 2;	  // Add average pacing delays
unsigned char emulator    = 1;     // Assume use emulator #1
unsigned int  emulators   = 1;	  // Assume 1 EMULATOR attached
unsigned char scroll      = 0;     // Do NOT scroll

void main(unsigned int ARGC,char *ARGV[])
{int i;

 printf("\n\n                      FlexROM II CAPTURE  %s",VER);
 printf("\n                      Copyright (c) 1996 TechTools");
 printf("\n                 voice: (972)272-9392 FAX:(972)494-5814");
 printf("\n           email: support@tech-tools.com   web:tech-tools.com\n");

 i=2;
 while(i<=ARGC)  // parse command-line flags
  {strptr = ARGV[i-1];
   if ((*strptr == '/') || (*strptr == '-'))   // start of a flag, parse it
	 { strptr++;
	   switch (*strptr)
	    { case 'p':
	      case 'P': // printer port base address
			   if (*++strptr == ':') strptr++;  // skip colons
			   port_addr = (int)hex2bin(strptr);
		    	break;

	      case 'd' :
	      case 'D' : // add delays
			   if (*++strptr == ':') strptr++;  // skip colons
			   pace = (unsigned char)hex2bin(strptr);
			   if (pace > 0x04) pace = 4;
			     break;

	      case 'e' :
	      case 'E' : // emulator to read the capture from
			   if (*++strptr == ':') strptr++;  // skip colons
			   emulator = ((unsigned char)atoi(strptr));
			   if (emulator == 0)
              emulator = 1;
			   break;

	      case 's' :
	      case 'S' : // SCROLL the display during capture
            scroll = 1;
            break;

	      default :
            printf("\nERROR: UNKNOWN FLAG '%c' FOUND",*strptr);
			   print_usage();
	     }
	   }
    else
      print_usage();

    i++;
   }

   e_count = fr2_init(port_addr,pace);

   if(e_count == 0xff)
	 {printf("\nERROR: Printer port NOT FOUND at %3.3X\n",port_addr);
	  print_usage();
    }

   if(e_count == 0)
	 {printf("\nERROR: NO emulators FOUND at %3.3X\n",port_addr);
	  print_usage();
    }

   if(emulator > e_count)
     {printf ("\nERROR: Emulator #%d not available",emulator);
      print_usage();
     }

  fr2_reset_target(0); // insure the target can run

  printf("\nEmulator #%d",emulator);

  printf("\n\nTRIG   Cap-addr INPUTs ACTIVITY");
  printf("\n----------------------------------\n");

  while(!kbhit())
   {stat = fr2_read_stat(emulator);
    if(scroll)
      printf("\n");
    else
      printf("\r");

    if(stat & 0x0100)      // look for trigger flag
      printf("TRIG ");
    else
      printf("-    ");

      // display capture address
    printf("  %6.6lX   ",fr2_read_cap(emulator));

    // print status input values
    printf("%d",(stat & 0x0080)?1:0);
    printf("%d",(stat & 0x0040)?1:0);
    printf("%d",(stat & 0x0020)?1:0);
    printf("%d",(stat & 0x0010)?1:0);

    if(!(stat & 0x0200))   // look for activity flag
      printf("  INACTIVE");
    else
      printf("  ACTIVE  ");
    if(kbhit())                 // if user pressed a key...
     { if(getch()== ' ')      //   and the key was a space...
         getch();             // Wait for another keypress
       else
         break;
     }
   }
  fr2_reset_target(0); // insure all emulators are de-selected.
}


void print_usage(void)
 {
   printf("\nUSAGE: FR2CAP ");
   printf("  [/Pxxx]  [/Dx]  [/Ex]  [/S]\n");

   printf("\n  FLAGS             DESCRIPTION                        DEFAULT");
   printf("\n  ---------------------------------------------------------------------");
   printf("\n   /P   Printer port address (in HEX)                  378");
   printf("\n   /D   Delay for slow ports (0,1,2,3,4) 4=>MAX delay  2");
   printf("\n   /E   Emulator number                                1");
   printf("\n   /S   SCROLL the display during capture              DO NOT SCROLL");
   printf("\n\n  Each FLAG is optional.");
   printf("\n  Flags may be entered in any order and MUST be seperated by spaces\n");
   printf("\n  The SPACE bar toggles a screen freeze. Any other key exits\n");
   exit(1);
 }

