#define VER "1.00"
#define hex2bin(str) strtol(str,NULL,16)

//////////////////////////////////////////////////////////////////////////
//
// FR2RESET.CPP
//
//	V 1.0   12/02/96	     	Jerry Merrill
//		- Initial Release
//
//
/////////////////////////////////////////////////////////////////////////
//
// This is a COMMAND-LINE program to set,clear or pulse the
// target reset pin.


#include <stdio.h>
#include <stdlib.h>
#include <conio.h>
#include <dos.h>
#include <string.h>
#include "fr2util.h"

// local prototypes
void print_usage(void);

// local variables
char *strptr;
unsigned char e_count;



// default parameters
unsigned int  port_addr   = 0x378; // MOST COMMON PRINTER ADDRESS
unsigned int  pace        = 2;	  // Add maximum pacing delays
unsigned char reset_flag  = 2;     // pulse reset

void main(unsigned int ARGC,char *ARGV[])
{int i;

 printf("\n\n                         FlexROM II RESET  %s",VER);
 printf("\n                      Copyright (c) 1996 TechTools");
 printf("\n                 voice: (972)272-9392 FAX:(972)494-5814");
 printf("\n           email: support@tech-tools.com   web:tech-tools.com\n");


// parse parameters (if any)
 i=2;
 while(i<=ARGC)  // parse command-line flags
  {strptr = ARGV[i-1];
   if ((*strptr == '/') || (*strptr == '-'))   // start of a flag, parse it
	 { strptr++;
	   switch (*strptr)
	    { case 'p':
	      case 'P': // printer port base address
			   if (*++strptr == ':') strptr++;  // skip colons
			   port_addr = (int)hex2bin(strptr);
		    	break;

	      case 'r' :
	      case 'R' : // RESET flag
			   if (*++strptr == ':') strptr++;  // skip colons
			   reset_flag = ((unsigned char)atoi(strptr));
            if(reset_flag >2)
              reset_flag = 2;
			   break;
	      default :
            printf("\nERROR: UNKNOWN FLAG '%c' FOUND",*strptr);
			   print_usage();
	     }
	   }
    else
      print_usage();

    i++;
   }

 // initialize and verify printer port

 e_count = fr2_init(port_addr,pace);

 if(e_count == 0xff)
   {printf("\nERROR: Printer port NOT FOUND at %3.3X\n",port_addr);
    print_usage();
   }

 if(e_count == 0)
   {printf("\nERROR: NO emulators FOUND at %3.3X\n",port_addr);
    print_usage();
   }


 if(reset_flag != 0)
   {printf("\nTarget RESET asserted.\n");
    fr2_reset_target(1);
   }

 if(reset_flag == 2)  // pulse reset....
   delay(1000);

 if(reset_flag != 1)
   { fr2_reset_target(0);
     printf("\nTarget RESET released\n");
   }
}


void print_usage(void)
 {
   printf("\nUSAGE: FR2RESET  ");
   printf("  [/Rx]  [/Pxxx]\n");

   printf("\n  FLAGS             DESCRIPTION                        DEFAULT");
   printf("\n  ---------------------------------------------------------------------");
   printf("\n   /R   RESET-FLAG (0,1,2) -> (OFF,ON,PULSE)           PULSE (2)");
   printf("\n   /P   Printer port address (in HEX)                  378");
   printf("\n\n  Each FLAG is optional.");
   printf("\n  Flags may be entered in any order and MUST be seperated by spaces\n");
   exit(1);
 }

