#define VER "1.00"
#define hex2bin(str) strtol(str,NULL,16)

//////////////////////////////////////////////////////////////////////////
//
// FR2TRIG.CPP
//
//	V 1.00   12/02/96	     	Jerry Merrill
//		- Initial RELEASE
//
//
/////////////////////////////////////////////////////////////////////////
//
// This is a COMMAND-LINE program to set the trigger value
// in a specified emulator.


#include <stdio.h>
#include <stdlib.h>
#include <conio.h>
#include <dos.h>
#include <string.h>
#include "fr2util.h"

// local prototypes
void print_usage(void);

// local variables
char *strptr;
unsigned char e_count;        // number of emulators attached


// default parameters
unsigned int  port_addr   = 0x378; // MOST COMMON PRINTER ADDRESS
unsigned int  pace        = 2;	  // Add maximum pacing delays
unsigned char emulator    = 1;     // Assume use emulator #1
unsigned int  emulators   = 1;	  // Assume 1 EMULATOR attached
unsigned long addr        = 0x0L;   // assume trigger address is 0

void main(unsigned int ARGC,char *ARGV[])
{int i;

 printf("\n\n                      FlexROM II Set Trigger  %s",VER);
 printf("\n                      Copyright (c) 1996 TechTools");
 printf("\n                 voice: (972)272-9392 FAX:(972)494-5814");
 printf("\n           email: support@tech-tools.com   web:tech-tools.com\n");

   // parse command line
 if (ARGC < 2)
    print_usage();

 addr = hex2bin(ARGV[1]);


 // parse any additional paramters
 i=3;
 while(i<=ARGC)  // parse command-line flags
  {strptr = ARGV[i-1];
   if ((*strptr == '/') || (*strptr == '-'))   // start of a flag, parse it
	 { strptr++;
	   switch (*strptr)
	    { case 'p':
	      case 'P': // printer port base address
			   if (*++strptr == ':') strptr++;  // skip colons
			   port_addr = (int)hex2bin(strptr);
		    	break;

	      case 'e' :
	      case 'E' : // emulator to set the trigger in
			   if (*++strptr == ':') strptr++;  // skip colons
			   emulator = ((unsigned char)atoi(strptr));
			   if (emulator == 0)
              emulator = 1;
			   break;

	      default :
            printf("\nERROR: UNKNOWN FLAG '%c' FOUND",*strptr);
			   print_usage();
	     }
	   }
    else
      print_usage();

    i++;
   }

   e_count = fr2_init(port_addr,pace);

   if(e_count == 0xff)
	 {printf("\nERROR: Printer port NOT FOUND at %3.3X\n",port_addr);
	  print_usage();
    }

   if(e_count == 0)
	 {printf("\nERROR: NO emulators FOUND at %3.3X\n",port_addr);
	  print_usage();
    }

   if(emulator > e_count)
     {printf ("\nERROR: Emulator #%d not available\n",emulator);
      print_usage();
     }

  fr2_set_add(emulator,addr);    // set the trigger address
  fr2_reset_target(0);                  // make sure reset is released
  printf("\nThe TRIGGER value of emulator #%d has been set to %lx.\n",
            emulator,addr);

}


void print_usage(void)
 {
   printf("\nUSAGE: FR2TRIG");
   printf("  TRIGGER_VALUE  [/Pxxx] [/Exx] \n");
   printf("\n  FLAGS             DESCRIPTION                        DEFAULT");
   printf("\n  ---------------------------------------------------------------------");
   printf("\n   /P   Printer port address (in HEX)                  378");
   printf("\n   /E   Emulator number                                1");
   printf("\n\n  Each FLAG is optional.");
   printf("\n  Flags may be entered in any order and MUST be seperated by spaces\n");
   exit(1);
 }

